pub struct ExclusiveCpu<'pin> { /* private fields */ }Expand description
Scoped proof of exclusive local access to CPU-owned mutable state.
In addition to migration exclusion, the caller that creates this token has excluded local IRQ/re-entry and every conflicting remote access.
Implementations
Sourceimpl ExclusiveCpu<'_>
impl ExclusiveCpu<'_>
Sourcepub const fn area(&self) -> CpuAreaRef
pub const fn area(&self) -> CpuAreaRef
Returns the initialized area covered by this stronger capability.